@@ -137,17 +137,18 @@ class HttpClient:
                     response.encoding = "UTF-8"
                     return response.status_code, response.text
 
-        except (
-            requests.exceptions.Timeout,
-            requests.exceptions.ConnectionError,
-        ):
-            message = "Connection failed or request timed out."
-            should_retry = True
-        except (requests.exceptions.RequestException, Exception) as e:
-            message = f"Unexpected connection error: {e}"
-            should_retry = False
-
-        raise ConnectionException(message, should_retry=should_retry)
+        except requests.exceptions.ConnectionError as e:
+            message = f"Connection failed: {e}"
+            raise ConnectionException(message, should_retry=True) from e
+        except requests.exceptions.Timeout as e:
+            message = f"Request timed out: {e}"
+            raise ConnectionException(message, should_retry=True) from e
+        except requests.exceptions.RequestException as e:
+            message = f"Request failed: {e}"
+            raise ConnectionException(message, should_retry=False) from e
+        except Exception as e:
+            message = f"Unexpected request failure: {e}"
+            raise ConnectionException(message, should_retry=False) from e
 
     def _should_retry(self, response, exception, num_retries):
         if num_retries >= max_network_retries:
