@@ -152,6 +152,11 @@ class GlossaryInfo:
     @staticmethod
     def from_json(json) -> "GlossaryInfo":
         """Create GlossaryInfo from the given API JSON object."""
+        # Workaround for bug in Python 3.6
+        creation_time = json["creation_time"]
+        if ":" == creation_time[-3:-2]:
+            creation_time = creation_time[:-3] + creation_time[-2:]
+
         return GlossaryInfo(
             json["glossary_id"],
             json["name"],
@@ -159,7 +164,7 @@ class GlossaryInfo:
             str(json["source_lang"]).upper(),
             str(json["target_lang"]).upper(),
             datetime.datetime.strptime(
-                json["creation_time"], "%Y-%m-%dT%H:%M:%S.%f%z"
+                creation_time, "%Y-%m-%dT%H:%M:%S.%f%z"
             ),
             int(json["entry_count"]),
         )
@@ -1005,7 +1010,7 @@ class Translator:
         self._raise_for_status(status, content, json, glossary=True)
         return GlossaryInfo.from_json(json)
 
-    def list_glossaries(self) -> list[GlossaryInfo]:
+    def list_glossaries(self) -> List[GlossaryInfo]:
         """Retrieves GlossaryInfo for all available glossaries.
 
         :return: list of GlossaryInfo for all available glossaries.
